/**
 * Copyright (c) 2012-2017, jcabi.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met: 1) Redistributions of source code must retain the above
 * copyright notice, this list of conditions and the following
 * disclaimer. 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution. 3) Neither the name of the jcabi.com nor
 * the names of its contributors may be used to endorse or promote
 * products derived from this software without specific prior written
 * permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.jcabi.log;

/**
 * Formats a log event using ANSI color codes.
 * @author Jose V. Dal Pra Junior (jrdalpra@gmail.com)
 * @version $Id: a6ddf33f5e9fb2dc4c9c21ee0812a4dd12a58670 $
 * @since 0.18
 */
class ColorfullyFormatted implements Formatted {

    /**
     * The basic information to be formatted with colors.
     */
    private final transient String basic;

    /**
     * Color used as the replacement.
     */
    private final transient String color;

    /**
     * Constructor.
     * @param bas Basic string to be formatted
     * @param col Color to be used to paint the output
     */
    ColorfullyFormatted(final String bas, final String col) {
        this.basic = bas;
        this.color = col;
    }

    @Override
    public String format() {
        return this.basic.replaceAll(
            new ControlSequenceIndicatorFormatted("%s\\?m").format(),
            String.format(
                "%s%sm",
                new ControlSequenceIndicatorFormatted("%s").format(),
                this.color
            )
        );
    }
}
